import subprocess
import os
import pathlib
from fastest.logger.logger import logger


def execute_coverage(report_path):
    """
    Function with a side-effect to create
    coverage report and prints to stdout
    :param report_path: str
    :return: None
    """
    subprocess.call(['coverage', 'report'])
    subprocess.call(['coverage', 'html'])
    coverage_path = os.path.join(report_path, 'htmlcov', 'index.html')
    logger.info(pathlib.Path(coverage_path).as_uri())



import coloredlogs, logging

# Create a logger object.
logger = logging.getLogger(__name__)

# By default the install() function installs a handler on the root logger,
# this means that log messages from your code and log messages from the
# libraries that you use will all show up on the terminal.
coloredlogs.install(fmt='%(hostname)s %(asctime)s %(levelname)s %(message)s', level='DEBUG', logger=logger)
